pub struct Cerr<F>where
F: MessageFormatter,{ /* private fields */ }Expand description
A logging Service that targets the standard error stream (std::io::stderr).
Cerr service is typically used for high-priority alerts or diagnostic
information that should remain visible even if stdout is redirected to a file.
Implementations