pub type StringFmt<F: MessageFormatter> = Fmt<String, F>;Expand description
A specialized alias for logging directly into a String.
This is commonly used for unit testing or collecting logs for display in a UI.
Note: Trait bounds on F are not enforced at definition time but are
checked during instantiation.
Aliased Type
pub struct StringFmt<F: MessageFormatter> { /* private fields */ }